pub struct BodyLimitConfig {
pub max_size: String,
pub parsed: usize,
pub display: bool,
}Expand description
Body Limit Configuration
Configuration for the Body Limit Layer This configuration allows you to set a maximum size for request bodies.
Fields:
-
max_size: A string representing the maximum allowed size for request bodies (e.g “1MB”, “500KB”). -
parsed: The parsed size in bytes (usize) derived frommax_size. -
display: A boolean indicating if the configuration should be displayed.
Fields
max_size: Stringparsed: usizedisplay: boolTrait Implementations
Sourceimpl Clone for BodyLimitConfig
impl Clone for BodyLimitConfig
Sourcefn clone(&self) -> BodyLimitConfig
fn clone(&self) -> BodyLimitConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BodyLimitConfig
impl Debug for BodyLimitConfig
Sourceimpl Default for BodyLimitConfig
impl Default for BodyLimitConfig
Sourceimpl<'de> Deserialize<'de> for BodyLimitConfig
impl<'de> Deserialize<'de> for BodyLimitConfig
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DisplayConfig for BodyLimitConfig
impl DisplayConfig for BodyLimitConfig