pub struct CompressionLayer;Expand description
Compression Layer
This struct represents the Compression Layer which enables response compression based on the provided configuration.
The layer is a wrapper around tower_http::compression::CompressionLayer.
Compress response bodies of the underlying service.
This uses the Accept-Encoding header to pick an appropriate encoding and adds the Content-Encoding header to responses.
Implementations
Sourceimpl CompressionLayer
impl CompressionLayer
pub fn new(config: &CompressionConfig) -> TowerCompressionLayer