XContentTypeOptions

Enum XContentTypeOptions 

pub enum XContentTypeOptions {
    NoSniff,
}
Manages X-Content-Type-Options header

The X-Content-Type-Options response HTTP header is a marker used by the server to indicate that the MIME types advertised in the Content-Type headers should not be changed and be followed. This allows to opt-out of MIME type sniffing, or, in other words, it is a way to say that the webmasters knew what they were doing.

Values

  • nosniff: Prevents the browser from MIME-sniffing a response away from the declared content-type. This also applies to Google Chrome, when downloading extensions.

Examples

use helmet_core::XContentTypeOptions;

let x_content_type_options = XContentTypeOptions::nosniff();

Variants



NoSniff

Implementations