pub struct SocketIoServerConfig {
pub enabled: bool,
pub ack_timeout: Option<TimeConfig>,
pub connect_timeout: Option<TimeConfig>,
pub max_buffer_size: Option<usize>,
pub max_payload: Option<ByteConfig>,
pub ping_interval: Option<TimeConfig>,
pub ping_timeout: Option<TimeConfig>,
pub req_path: Option<String>,
pub transports: Option<Vec<String>>,
pub parser: Option<String>,
pub ws_read_buffer_size: Option<usize>,
pub display: bool,
}Fields
enabled: boolWhether to enable the Socket.IO server. Defaults to false.
ack_timeout: Option<TimeConfig>The amount of time the server will wait for an acknowledgement from the client before closing the connection.
Defaults to 5 seconds.
connect_timeout: Option<TimeConfig>The amount of time before disconnecting a client that has not successfully joined a namespace.
Defaults to 45 seconds.
max_buffer_size: Option<usize>The maximum number of packets that can be buffered per connection before being emitted to the client. If the buffer if full the emit() method will return an error.
Defaults to 128 packets.
max_payload: Option<ByteConfig>The maximum size of a payload in bytes. If a payload is bigger than this value the emit() method will return an error.
Defaults to 100 kb.
ping_interval: Option<TimeConfig>The interval at which the server will send a ping packet to the client. Defaults to 25 seconds.
ping_timeout: Option<TimeConfig>The amount of time the server will wait for a ping response from the client before closing the connection.
Defaults to 20 seconds.
req_path: Option<String>The path to listen for socket.io requests on. Defaults to “/socket.io”.
transports: Option<Vec<String>>The transports to allow for connections. Valid options are “polling” and “websocket”.
parser: Option<String>The parser to use for encoding and decoding messages. Valid options are “common” and “msgpack”.
ws_read_buffer_size: Option<usize>The size of the read buffer for the websocket transport. You can tweak this value depending on your use case.
Defaults to 4KiB.
Setting it to a higher value will improve performance on heavy read scenarios but will consume more memory.
display: boolWhether to display the configuration on startup.